==> kubernetes-model-core-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/NamedExtensionFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.String;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;

 /**
  * Generated
  */
public interface NamedExtensionFluent<A extends io.fabric8.kubernetes.api.model.NamedExtensionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildExtension instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.HasMetadata getExtension();
  public io.fabric8.kubernetes.api.model.HasMetadata buildExtension();
  public A withExtension(io.fabric8.kubernetes.api.model.HasMetadata extension);
  public java.lang.Boolean hasExtension();
  public A withLimitRangeExtension(io.fabric8.kubernetes.api.model.LimitRange limitRangeExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.LimitRangeExtensionNested<A> withNewLimitRangeExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.LimitRangeExtensionNested<A> withNewLimitRangeExtensionLike(io.fabric8.kubernetes.api.model.LimitRange item);
  public A withAPIServiceExtension(io.fabric8.kubernetes.api.model.APIService aPIServiceExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.APIServiceExtensionNested<A> withNewAPIServiceExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.APIServiceExtensionNested<A> withNewAPIServiceExtensionLike(io.fabric8.kubernetes.api.model.APIService item);
  public A withNamespaceExtension(io.fabric8.kubernetes.api.model.Namespace namespaceExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.NamespaceExtensionNested<A> withNewNamespaceExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.NamespaceExtensionNested<A> withNewNamespaceExtensionLike(io.fabric8.kubernetes.api.model.Namespace item);
  public A withServiceExtension(io.fabric8.kubernetes.api.model.Service serviceExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceExtensionNested<A> withNewServiceExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceExtensionNested<A> withNewServiceExtensionLike(io.fabric8.kubernetes.api.model.Service item);
  public A withReplicationControllerExtension(io.fabric8.kubernetes.api.model.ReplicationController replicationControllerExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ReplicationControllerExtensionNested<A> withNewReplicationControllerExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ReplicationControllerExtensionNested<A> withNewReplicationControllerExtensionLike(io.fabric8.kubernetes.api.model.ReplicationController item);
  public A withPodTemplateExtension(io.fabric8.kubernetes.api.model.PodTemplate podTemplateExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodTemplateExtensionNested<A> withNewPodTemplateExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodTemplateExtensionNested<A> withNewPodTemplateExtensionLike(io.fabric8.kubernetes.api.model.PodTemplate item);
  public A withEventExtension(io.fabric8.kubernetes.api.model.Event eventExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.EventExtensionNested<A> withNewEventExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.EventExtensionNested<A> withNewEventExtensionLike(io.fabric8.kubernetes.api.model.Event item);
  public A withPersistentVolumeExtension(io.fabric8.kubernetes.api.model.PersistentVolume persistentVolumeExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeExtensionNested<A> withNewPersistentVolumeExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeExtensionNested<A> withNewPersistentVolumeExtensionLike(io.fabric8.kubernetes.api.model.PersistentVolume item);
  public A withPersistentVolumeClaimExtension(io.fabric8.kubernetes.api.model.PersistentVolumeClaim persistentVolumeClaimExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeClaimExtensionNested<A> withNewPersistentVolumeClaimExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeClaimExtensionNested<A> withNewPersistentVolumeClaimExtensionLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaim item);
  public A withEndpointsExtension(io.fabric8.kubernetes.api.model.Endpoints endpointsExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.EndpointsExtensionNested<A> withNewEndpointsExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.EndpointsExtensionNested<A> withNewEndpointsExtensionLike(io.fabric8.kubernetes.api.model.Endpoints item);
  public A withPodExtension(io.fabric8.kubernetes.api.model.Pod podExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodExtensionNested<A> withNewPodExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodExtensionNested<A> withNewPodExtensionLike(io.fabric8.kubernetes.api.model.Pod item);
  public A withConfigMapExtension(io.fabric8.kubernetes.api.model.ConfigMap configMapExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ConfigMapExtensionNested<A> withNewConfigMapExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ConfigMapExtensionNested<A> withNewConfigMapExtensionLike(io.fabric8.kubernetes.api.model.ConfigMap item);
  public A withComponentStatusExtension(io.fabric8.kubernetes.api.model.ComponentStatus componentStatusExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ComponentStatusExtensionNested<A> withNewComponentStatusExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ComponentStatusExtensionNested<A> withNewComponentStatusExtensionLike(io.fabric8.kubernetes.api.model.ComponentStatus item);
  public A withBindingExtension(io.fabric8.kubernetes.api.model.Binding bindingExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.BindingExtensionNested<A> withNewBindingExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.BindingExtensionNested<A> withNewBindingExtensionLike(io.fabric8.kubernetes.api.model.Binding item);
  public A withResourceQuotaExtension(io.fabric8.kubernetes.api.model.ResourceQuota resourceQuotaExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ResourceQuotaExtensionNested<A> withNewResourceQuotaExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ResourceQuotaExtensionNested<A> withNewResourceQuotaExtensionLike(io.fabric8.kubernetes.api.model.ResourceQuota item);
  public A withSecretExtension(io.fabric8.kubernetes.api.model.Secret secretExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.SecretExtensionNested<A> withNewSecretExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.SecretExtensionNested<A> withNewSecretExtensionLike(io.fabric8.kubernetes.api.model.Secret item);
  public A withNodeExtension(io.fabric8.kubernetes.api.model.Node nodeExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.NodeExtensionNested<A> withNewNodeExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.NodeExtensionNested<A> withNewNodeExtensionLike(io.fabric8.kubernetes.api.model.Node item);
  public A withServiceAccountExtension(io.fabric8.kubernetes.api.model.ServiceAccount serviceAccountExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceAccountExtensionNested<A> withNewServiceAccountExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceAccountExtensionNested<A> withNewServiceAccountExtensionLike(io.fabric8.kubernetes.api.model.ServiceAccount item);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public interface LimitRangeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LimitRangeFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.LimitRangeExtensionNested<N>>{
    public N and();
    public N endLimitRangeExtension();
    
  }
  public interface APIServiceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.APIServiceFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.APIServiceExtensionNested<N>>{
    public N and();
    public N endAPIServiceExtension();
    
  }
  public interface NamespaceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.NamespaceFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.NamespaceExtensionNested<N>>{
    public N and();
    public N endNamespaceExtension();
    
  }
  public interface ServiceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ServiceFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceExtensionNested<N>>{
    public N and();
    public N endServiceExtension();
    
  }
  public interface ReplicationControllerExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ReplicationControllerFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ReplicationControllerExtensionNested<N>>{
    public N and();
    public N endReplicationControllerExtension();
    
  }
  public interface PodTemplateExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PodTemplateFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodTemplateExtensionNested<N>>{
    public N and();
    public N endPodTemplateExtension();
    
  }
  public interface EventExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.EventFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.EventExtensionNested<N>>{
    public N and();
    public N endEventExtension();
    
  }
  public interface PersistentVolumeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PersistentVolumeFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeExtensionNested<N>>{
    public N and();
    public N endPersistentVolumeExtension();
    
  }
  public interface PersistentVolumeClaimExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PersistentVolumeClaimFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeClaimExtensionNested<N>>{
    public N and();
    public N endPersistentVolumeClaimExtension();
    
  }
  public interface EndpointsExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.EndpointsFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.EndpointsExtensionNested<N>>{
    public N and();
    public N endEndpointsExtension();
    
  }
  public interface PodExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PodFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodExtensionNested<N>>{
    public N and();
    public N endPodExtension();
    
  }
  public interface ConfigMapExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ConfigMapFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ConfigMapExtensionNested<N>>{
    public N and();
    public N endConfigMapExtension();
    
  }
  public interface ComponentStatusExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ComponentStatusFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ComponentStatusExtensionNested<N>>{
    public N and();
    public N endComponentStatusExtension();
    
  }
  public interface BindingExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.BindingFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.BindingExtensionNested<N>>{
    public N and();
    public N endBindingExtension();
    
  }
  public interface ResourceQuotaExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ResourceQuotaFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ResourceQuotaExtensionNested<N>>{
    public N and();
    public N endResourceQuotaExtension();
    
  }
  public interface SecretExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.SecretExtensionNested<N>>{
    public N and();
    public N endSecretExtension();
    
  }
  public interface NodeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.NodeFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.NodeExtensionNested<N>>{
    public N and();
    public N endNodeExtension();
    
  }
  public interface ServiceAccountExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ServiceAccountFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceAccountExtensionNested<N>>{
    public N and();
    public N endServiceAccountExtension();
    
  }
  
}

==> kubernetes-model-core-5.10.0-sources.jar: io/fabric8/kubernetes/api/model/NamedExtensionFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.String;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;
import java.lang.Deprecated;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;

 /**
  * Generated
  */
public interface NamedExtensionFluent<A extends io.fabric8.kubernetes.api.model.NamedExtensionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildExtension instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.HasMetadata getExtension();
  public io.fabric8.kubernetes.api.model.HasMetadata buildExtension();
  public A withExtension(io.fabric8.kubernetes.api.model.HasMetadata extension);
  public java.lang.Boolean hasExtension();
  public A withLimitRangeExtension(io.fabric8.kubernetes.api.model.LimitRange limitRangeExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.LimitRangeExtensionNested<A> withNewLimitRangeExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.LimitRangeExtensionNested<A> withNewLimitRangeExtensionLike(io.fabric8.kubernetes.api.model.LimitRange item);
  public A withAPIServiceExtension(io.fabric8.kubernetes.api.model.APIService aPIServiceExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.APIServiceExtensionNested<A> withNewAPIServiceExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.APIServiceExtensionNested<A> withNewAPIServiceExtensionLike(io.fabric8.kubernetes.api.model.APIService item);
  public A withNamespaceExtension(io.fabric8.kubernetes.api.model.Namespace namespaceExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.NamespaceExtensionNested<A> withNewNamespaceExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.NamespaceExtensionNested<A> withNewNamespaceExtensionLike(io.fabric8.kubernetes.api.model.Namespace item);
  public A withServiceExtension(io.fabric8.kubernetes.api.model.Service serviceExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceExtensionNested<A> withNewServiceExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceExtensionNested<A> withNewServiceExtensionLike(io.fabric8.kubernetes.api.model.Service item);
  public A withReplicationControllerExtension(io.fabric8.kubernetes.api.model.ReplicationController replicationControllerExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ReplicationControllerExtensionNested<A> withNewReplicationControllerExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ReplicationControllerExtensionNested<A> withNewReplicationControllerExtensionLike(io.fabric8.kubernetes.api.model.ReplicationController item);
  public A withPodTemplateExtension(io.fabric8.kubernetes.api.model.PodTemplate podTemplateExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodTemplateExtensionNested<A> withNewPodTemplateExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodTemplateExtensionNested<A> withNewPodTemplateExtensionLike(io.fabric8.kubernetes.api.model.PodTemplate item);
  public A withEventExtension(io.fabric8.kubernetes.api.model.Event eventExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.EventExtensionNested<A> withNewEventExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.EventExtensionNested<A> withNewEventExtensionLike(io.fabric8.kubernetes.api.model.Event item);
  public A withPersistentVolumeExtension(io.fabric8.kubernetes.api.model.PersistentVolume persistentVolumeExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeExtensionNested<A> withNewPersistentVolumeExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeExtensionNested<A> withNewPersistentVolumeExtensionLike(io.fabric8.kubernetes.api.model.PersistentVolume item);
  public A withPersistentVolumeClaimExtension(io.fabric8.kubernetes.api.model.PersistentVolumeClaim persistentVolumeClaimExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeClaimExtensionNested<A> withNewPersistentVolumeClaimExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeClaimExtensionNested<A> withNewPersistentVolumeClaimExtensionLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaim item);
  public A withEndpointsExtension(io.fabric8.kubernetes.api.model.Endpoints endpointsExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.EndpointsExtensionNested<A> withNewEndpointsExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.EndpointsExtensionNested<A> withNewEndpointsExtensionLike(io.fabric8.kubernetes.api.model.Endpoints item);
  public A withPodExtension(io.fabric8.kubernetes.api.model.Pod podExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodExtensionNested<A> withNewPodExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodExtensionNested<A> withNewPodExtensionLike(io.fabric8.kubernetes.api.model.Pod item);
  public A withConfigMapExtension(io.fabric8.kubernetes.api.model.ConfigMap configMapExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ConfigMapExtensionNested<A> withNewConfigMapExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ConfigMapExtensionNested<A> withNewConfigMapExtensionLike(io.fabric8.kubernetes.api.model.ConfigMap item);
  public A withComponentStatusExtension(io.fabric8.kubernetes.api.model.ComponentStatus componentStatusExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ComponentStatusExtensionNested<A> withNewComponentStatusExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ComponentStatusExtensionNested<A> withNewComponentStatusExtensionLike(io.fabric8.kubernetes.api.model.ComponentStatus item);
  public A withBindingExtension(io.fabric8.kubernetes.api.model.Binding bindingExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.BindingExtensionNested<A> withNewBindingExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.BindingExtensionNested<A> withNewBindingExtensionLike(io.fabric8.kubernetes.api.model.Binding item);
  public A withResourceQuotaExtension(io.fabric8.kubernetes.api.model.ResourceQuota resourceQuotaExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ResourceQuotaExtensionNested<A> withNewResourceQuotaExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ResourceQuotaExtensionNested<A> withNewResourceQuotaExtensionLike(io.fabric8.kubernetes.api.model.ResourceQuota item);
  public A withSecretExtension(io.fabric8.kubernetes.api.model.Secret secretExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.SecretExtensionNested<A> withNewSecretExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.SecretExtensionNested<A> withNewSecretExtensionLike(io.fabric8.kubernetes.api.model.Secret item);
  public A withNodeExtension(io.fabric8.kubernetes.api.model.Node nodeExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.NodeExtensionNested<A> withNewNodeExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.NodeExtensionNested<A> withNewNodeExtensionLike(io.fabric8.kubernetes.api.model.Node item);
  public A withServiceAccountExtension(io.fabric8.kubernetes.api.model.ServiceAccount serviceAccountExtension);
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceAccountExtensionNested<A> withNewServiceAccountExtension();
  public io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceAccountExtensionNested<A> withNewServiceAccountExtensionLike(io.fabric8.kubernetes.api.model.ServiceAccount item);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface LimitRangeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LimitRangeFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.LimitRangeExtensionNested<N>>{
    public N and();
    public N endLimitRangeExtension();
    
  }
  public interface APIServiceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.APIServiceFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.APIServiceExtensionNested<N>>{
    public N and();
    public N endAPIServiceExtension();
    
  }
  public interface NamespaceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.NamespaceFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.NamespaceExtensionNested<N>>{
    public N and();
    public N endNamespaceExtension();
    
  }
  public interface ServiceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ServiceFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceExtensionNested<N>>{
    public N and();
    public N endServiceExtension();
    
  }
  public interface ReplicationControllerExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ReplicationControllerFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ReplicationControllerExtensionNested<N>>{
    public N and();
    public N endReplicationControllerExtension();
    
  }
  public interface PodTemplateExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PodTemplateFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodTemplateExtensionNested<N>>{
    public N and();
    public N endPodTemplateExtension();
    
  }
  public interface EventExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.EventFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.EventExtensionNested<N>>{
    public N and();
    public N endEventExtension();
    
  }
  public interface PersistentVolumeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PersistentVolumeFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeExtensionNested<N>>{
    public N and();
    public N endPersistentVolumeExtension();
    
  }
  public interface PersistentVolumeClaimExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PersistentVolumeClaimFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.PersistentVolumeClaimExtensionNested<N>>{
    public N and();
    public N endPersistentVolumeClaimExtension();
    
  }
  public interface EndpointsExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.EndpointsFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.EndpointsExtensionNested<N>>{
    public N and();
    public N endEndpointsExtension();
    
  }
  public interface PodExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PodFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.PodExtensionNested<N>>{
    public N and();
    public N endPodExtension();
    
  }
  public interface ConfigMapExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ConfigMapFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ConfigMapExtensionNested<N>>{
    public N and();
    public N endConfigMapExtension();
    
  }
  public interface ComponentStatusExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ComponentStatusFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ComponentStatusExtensionNested<N>>{
    public N and();
    public N endComponentStatusExtension();
    
  }
  public interface BindingExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.BindingFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.BindingExtensionNested<N>>{
    public N and();
    public N endBindingExtension();
    
  }
  public interface ResourceQuotaExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ResourceQuotaFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ResourceQuotaExtensionNested<N>>{
    public N and();
    public N endResourceQuotaExtension();
    
  }
  public interface SecretExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.SecretExtensionNested<N>>{
    public N and();
    public N endSecretExtension();
    
  }
  public interface NodeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.NodeFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.NodeExtensionNested<N>>{
    public N and();
    public N endNodeExtension();
    
  }
  public interface ServiceAccountExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ServiceAccountFluent<io.fabric8.kubernetes.api.model.NamedExtensionFluent.ServiceAccountExtensionNested<N>>{
    public N and();
    public N endServiceAccountExtension();
    
  }
  
}
